==> types-fpdf2-2.5.4.2.tar.gz: types-fpdf2-2.5.4.2/CHANGELOG.md <==
## 2.5.4.2 (2022-10-06)

`fpdf2`: complete stubs (#8855)

## 2.5.4.1 (2022-10-04)

`fpdf2`: Add missing files (#8836)

## 2.5.4 (2022-09-11)

Update `fdpf2` stubs for v2.5.7 (#8721)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2.5.3 (2022-08-30)

`fpdf2`: Remove redundant `str | Literal['DEPRECATED']` union (#8650)

## 2.5.2 (2022-08-17)

fpdf2: fix for 2.5.6 changes (#8546)

Life is much easier when upstream has some annotations

Fixes #8545

## 2.5.1 (2022-07-04)

Fix size parameter of FPDF.set_font_size (#8234)

## 2.5.0 (2022-06-29)

Bump fpdf2 to 2.5.* (#8173)

Co-authored-by: hauntsaninja <>
Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 2.4.9 (2022-06-26)

fpdf2: improve types (#8176)

Co-authored-by: hauntsaninja <>

## 2.4.8 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 2.4.7 (2022-02-10)

fpdf2: Correct annotations of @contextmanager methods (#7172)

## 2.4.5 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.4.4 (2021-12-23)

Fix third-party issues found by stubtest (#6667)

## 2.4.3 (2021-12-21)

Add some missing attributes and types to FPDF (#6618)

## 2.4.2 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 2.4.1 (2021-11-16)

Improve fpdf.image_parsing (#6313)

* Annotate more attributes, arguments, and return types.
* Add "dims" argument to get_img_info(), added in 2.4.6.

## 2.4.0 (2021-11-10)

Add stubs for fpdf2 (#6252)

==> types-fpdf2-2.6.0.0.tar.gz: types-fpdf2-2.6.0.0/CHANGELOG.md <==
## 2.6.0.0 (2022-11-23)

Update fpdf2 stubs to 2.6 (#9236)

Mark first argument of `__[get|set|del]attr__` as `str` (#9245)

## 2.5.4.3 (2022-10-14)

Add return types to fpdf.drawing (#8891)

Co-authored-by: Akuli <akuviljanen17@gmail.com>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 2.5.4.2 (2022-10-06)

`fpdf2`: complete stubs (#8855)

## 2.5.4.1 (2022-10-04)

`fpdf2`: Add missing files (#8836)

## 2.5.4 (2022-09-11)

Update `fdpf2` stubs for v2.5.7 (#8721)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2.5.3 (2022-08-30)

`fpdf2`: Remove redundant `str | Literal['DEPRECATED']` union (#8650)

## 2.5.2 (2022-08-17)

fpdf2: fix for 2.5.6 changes (#8546)

Life is much easier when upstream has some annotations

Fixes #8545

## 2.5.1 (2022-07-04)

Fix size parameter of FPDF.set_font_size (#8234)

## 2.5.0 (2022-06-29)

Bump fpdf2 to 2.5.* (#8173)

Co-authored-by: hauntsaninja <>
Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 2.4.9 (2022-06-26)

fpdf2: improve types (#8176)

Co-authored-by: hauntsaninja <>

## 2.4.8 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 2.4.7 (2022-02-10)

fpdf2: Correct annotations of @contextmanager methods (#7172)

## 2.4.5 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.4.4 (2021-12-23)

Fix third-party issues found by stubtest (#6667)

## 2.4.3 (2021-12-21)

Add some missing attributes and types to FPDF (#6618)

## 2.4.2 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 2.4.1 (2021-11-16)

Improve fpdf.image_parsing (#6313)

* Annotate more attributes, arguments, and return types.
* Add "dims" argument to get_img_info(), added in 2.4.6.

## 2.4.0 (2021-11-10)

Add stubs for fpdf2 (#6252)
